@@ -12,6 +12,10 @@ def guessGame_1_10_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
         
@@ -28,6 +32,10 @@ def guessGame_1_100_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 def guessGame_1_1000_Easy():
     number = random.randint(1,1000)
@@ -44,6 +52,10 @@ def guessGame_1_1000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 def guessGame_1_10000_Easy():
     number = random.randint(1,10000)
@@ -58,6 +70,10 @@ def guessGame_1_10000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 def guessGame_1_100000_Easy():
     number = random.randint(1,100000)
@@ -72,6 +88,10 @@ def guessGame_1_100000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 def guessGame_1_1000000_Easy():
     number = random.randint(1,1000000)
@@ -86,6 +106,10 @@ def guessGame_1_1000000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 def guessGame_1_10000000_Easy():
     number = random.randint(1,10000000)
@@ -100,6 +124,10 @@ def guessGame_1_10000000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 def guessGame_1_100000000_Easy():
     number = random.randint(1,100000000)
@@ -114,6 +142,10 @@ def guessGame_1_100000000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 def guessGame_1_1000000000_Easy():
@@ -129,6 +161,10 @@ def guessGame_1_1000000000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 
@@ -145,6 +181,10 @@ def guessGame_1_10000000000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 def guessGame_1_100000000000_Easy():
@@ -160,6 +200,10 @@ def guessGame_1_100000000000_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 
@@ -176,6 +220,10 @@ def guessGame_1_999999999999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 
@@ -192,6 +240,10 @@ def guessGame_1_9_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 
@@ -208,6 +260,10 @@ def guessGame_1_99_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 
@@ -224,6 +280,10 @@ def guessGame_1_999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 
@@ -240,6 +300,10 @@ def guessGame_1_9999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 def guessGame_1_99999_Easy():
@@ -255,6 +319,10 @@ def guessGame_1_99999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 
@@ -271,6 +339,10 @@ def guessGame_1_999999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 def guessGame_1_9999999_Easy():
@@ -286,6 +358,10 @@ def guessGame_1_9999999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 def guessGame_1_99999999_Easy():
@@ -301,6 +377,10 @@ def guessGame_1_99999999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 def guessGame_1_999999999_Easy():
@@ -316,6 +396,10 @@ def guessGame_1_999999999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 
@@ -332,13 +416,17 @@ def guessGame_1_9999999999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
 def guessGame_1_99999999999_Easy():
     number = random.randint(1,99999999999)
     ettempt = 1
     Round = 3
-     while ettempt != 3 and Round == 3:
+    while ettempt != 3 and Round == 3:
         guess = input('请输入你的数字:')
         if number == int(guess):
             print('太棒了，你猜对了!')
@@ -347,5 +435,9 @@ def guessGame_1_99999999999_Easy():
             print('sorry wrong,the collect int is: '+str(number))
         else:
             print('sorry wrong,please guess again')
+            if number < int(guess):
+                print('you\'s guess are too big')
+            else:
+                print('you\'s guess are too small')
             ettempt = ettempt + 1
 
